@@ -82,9 +82,10 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
     let args: Args = util::get_args(USAGE, argv)?;
 
     let regexset = read_regexset(&*args.arg_regexset_file)?;
-    let regex_unicode = match env::var("QSV_REGEX_UNICODE") {
-        Ok(_) => true,
-        Err(_) => args.flag_unicode,
+    let regex_unicode = if env::var("QSV_REGEX_UNICODE").is_ok() {
+        true
+    } else {
+        args.flag_unicode
     };
     let pattern = RegexSetBuilder::new(&regexset)
         .case_insensitive(args.flag_ignore_case)
@@ -109,13 +110,13 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
         wtr.write_record(&headers)?;
     }
 
-    let mut match_list: String = String::from("");
+    let mut match_list: String = String::new();
     let do_match_list = args.flag_flag.is_some();
 
     let mut record = csv::ByteRecord::new();
     let mut flag_rowi: u64 = 1;
-    let mut _matched_rows = String::from("");
-    let mut _match_list_with_row = String::from("");
+    let mut _matched_rows = String::new();
+    let mut _match_list_with_row = String::new();
     while rdr.read_byte_record(&mut record)? {
         let mut m = sel.select(&record).any(|f| {
             let matched = pattern.is_match(f);
@@ -124,7 +125,7 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
                 for j in &mut matches {
                     *j += 1; // so the list is human readable - i.e. not zero-based
                 }
-                match_list = format!("{:?}", matches);
+                match_list = format!("{matches:?}");
             }
             matched
         });
@@ -139,7 +140,7 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
                 if args.flag_invert_match {
                     _matched_rows.as_bytes()
                 } else {
-                    _match_list_with_row = format!("{};{}", _matched_rows, match_list);
+                    _match_list_with_row = format!("{_matched_rows};{match_list}");
                     _match_list_with_row.as_bytes()
                 }
             } else {
